==> jc-1.4.0.tar.gz: java/util/jar/JarEntry.h <==
// public class java.util.jar.JarEntry

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 63aef4241f448a25 java_util_jar_JarEntry
// @dep_class 1645f313fb808b9f java_util_zip_ZipEntry

// header file dependencies
// @dep_header java_util_zip_ZipEntry

#include "java/util/zip/ZipEntry.h"

#ifndef _JC_java_util_jar_JarEntry_H_
#define _JC_java_util_jar_JarEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_jar_Attributes$object;
struct _jc_java_util_jar_JarEntry$object;
struct _jc_java_util_zip_ZipEntry$object;

// Typedefs
typedef struct _jc_java_util_jar_JarEntry$sub_refs	_jc_java_util_jar_JarEntry$sub_refs;
typedef struct _jc_java_util_jar_JarEntry$sub_nonrefs	_jc_java_util_jar_JarEntry$sub_nonrefs;
typedef struct _jc_java_util_jar_JarEntry$refs	_jc_java_util_jar_JarEntry$refs;
typedef struct _jc_java_util_jar_JarEntry$nonrefs	_jc_java_util_jar_JarEntry$nonrefs;
typedef struct _jc_java_util_jar_JarEntry$object	_jc_java_util_jar_JarEntry$object;

typedef const struct _jc_java_util_jar_JarEntry$vmethods	_jc_java_util_jar_JarEntry$vmethods;
typedef const struct _jc_java_util_jar_JarEntry$vtable	_jc_java_util_jar_JarEntry$vtable;
typedef const struct _jc_java_util_jar_JarEntry$vtype	_jc_java_util_jar_JarEntry$vtype;

// Constructors
extern void _jc_java_util_jar_JarEntry$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_util_jar_JarEntry$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_util_jar_JarEntry$method$_init$94c52f14c2d985b6(_jc_env *, struct _jc_java_util_jar_JarEntry$object *, struct _jc_java_util_jar_JarEntry$object *);
extern void _jc_java_util_jar_JarEntry$method$_init$7af37fb0fe509790(_jc_env *, struct _jc_java_util_jar_JarEntry$object *, struct _jc_java_util_zip_ZipEntry$object *);

// Virtual methods
extern struct _jc_java_util_jar_Attributes$object *_jc_java_util_jar_JarEntry$method$getAttributes$bbb8b0fff5df988b(_jc_env *, struct _jc_java_util_jar_JarEntry$object *);
extern _jc_object_array *_jc_java_util_jar_JarEntry$method$getCertificates$39b82b17735f6833(_jc_env *, struct _jc_java_util_jar_JarEntry$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_jar_JarEntry$method_info$getAttributes$bbb8b0fff5df988b;
extern _jc_method _jc_java_util_jar_JarEntry$method_info$getCertificates$39b82b17735f6833;

// Virtual methods structure
struct _jc_java_util_jar_JarEntry$vmethods {
	struct _jc_java_util_jar_Attributes$object	*(*getAttributes$bbb8b0fff5df988b)(_jc_env *, struct _jc_java_util_jar_JarEntry$object *);
	_jc_object_array	*(*getCertificates$39b82b17735f6833)(_jc_env *, struct _jc_java_util_jar_JarEntry$object *);
};

// Vtable
struct _jc_java_util_jar_JarEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_zip_ZipEntry$vmethods	java_util_zip_ZipEntry;
	_jc_java_util_jar_JarEntry$vmethods	java_util_jar_JarEntry;
};

// Vtype
struct _jc_java_util_jar_JarEntry$vtype {
	_jc_type			type;
	_jc_java_util_jar_JarEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_jar_JarEntry$sub_refs {
	struct _jc_java_util_jar_Attributes$object	*attr;
	_jc_object_array	*certs;
};

// Reference instance fields (object)
struct _jc_java_util_jar_JarEntry$refs {
    _jc_java_util_jar_JarEntry$sub_refs	java_util_jar_JarEntry;
    _jc_java_util_zip_ZipEntry$sub_refs	java_util_zip_ZipEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_jar_JarEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_jar_JarEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_zip_ZipEntry$sub_nonrefs	java_util_zip_ZipEntry;
    _jc_java_util_jar_JarEntry$sub_nonrefs	java_util_jar_JarEntry;
};

// Object instance structure
struct _jc_java_util_jar_JarEntry$object {
	_jc_java_util_jar_JarEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_jar_JarEntry$vtype	*vtype;
	_jc_java_util_jar_JarEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_jar_JarEntry$vtype _jc_java_util_jar_JarEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_jar_JarEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_jar_JarEntry$class_object;

#endif	/* _JC_java_util_jar_JarEntry_H_ */

==> jc-1.4.6.tar.gz: java/util/jar/JarEntry.h <==
// public class java.util.jar.JarEntry

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 63aef4241f448a25 java_util_jar_JarEntry
// @dep_class 1645f313fb808b9f java_util_zip_ZipEntry

// header file dependencies
// @dep_header java_util_zip_ZipEntry

#include "java/util/zip/ZipEntry.h"

#ifndef _JC_java_util_jar_JarEntry_H_
#define _JC_java_util_jar_JarEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_jar_Attributes$object;
struct _jc_java_util_jar_JarEntry$object;
struct _jc_java_util_zip_ZipEntry$object;

// Typedefs
typedef struct _jc_java_util_jar_JarEntry$sub_refs	_jc_java_util_jar_JarEntry$sub_refs;
typedef struct _jc_java_util_jar_JarEntry$sub_nonrefs	_jc_java_util_jar_JarEntry$sub_nonrefs;
typedef struct _jc_java_util_jar_JarEntry$refs	_jc_java_util_jar_JarEntry$refs;
typedef struct _jc_java_util_jar_JarEntry$nonrefs	_jc_java_util_jar_JarEntry$nonrefs;
typedef struct _jc_java_util_jar_JarEntry$object	_jc_java_util_jar_JarEntry$object;

typedef const struct _jc_java_util_jar_JarEntry$vmethods	_jc_java_util_jar_JarEntry$vmethods;
typedef const struct _jc_java_util_jar_JarEntry$vtable	_jc_java_util_jar_JarEntry$vtable;
typedef const struct _jc_java_util_jar_JarEntry$vtype	_jc_java_util_jar_JarEntry$vtype;

// Constructors
extern void _jc_java_util_jar_JarEntry$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_util_jar_JarEntry$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_jar_JarEntry$method$_init$94c52f14c2d985b6(_jc_env *, struct _jc_java_util_jar_JarEntry$object *, struct _jc_java_util_jar_JarEntry$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_jar_JarEntry$method$_init$7af37fb0fe509790(_jc_env *, struct _jc_java_util_jar_JarEntry$object *, struct _jc_java_util_zip_ZipEntry$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_jar_Attributes$object *_jc_java_util_jar_JarEntry$method$getAttributes$bbb8b0fff5df988b(_jc_env *, struct _jc_java_util_jar_JarEntry$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_java_util_jar_JarEntry$method$getCertificates$39b82b17735f6833(_jc_env *, struct _jc_java_util_jar_JarEntry$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_jar_JarEntry$method_info$getAttributes$bbb8b0fff5df988b;
extern _jc_method _jc_java_util_jar_JarEntry$method_info$getCertificates$39b82b17735f6833;

// Virtual methods structure
struct _jc_java_util_jar_JarEntry$vmethods {
	struct _jc_java_util_jar_Attributes$object	*(*getAttributes$bbb8b0fff5df988b)(_jc_env *, struct _jc_java_util_jar_JarEntry$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getCertificates$39b82b17735f6833)(_jc_env *, struct _jc_java_util_jar_JarEntry$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_jar_JarEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_zip_ZipEntry$vmethods	java_util_zip_ZipEntry;
	_jc_java_util_jar_JarEntry$vmethods	java_util_jar_JarEntry;
};

// Vtype
struct _jc_java_util_jar_JarEntry$vtype {
	_jc_type			type;
	_jc_java_util_jar_JarEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_jar_JarEntry$sub_refs {
	struct _jc_java_util_jar_Attributes$object	*attr;
	_jc_object_array	*certs;
};

// Reference instance fields (object)
struct _jc_java_util_jar_JarEntry$refs {
    _jc_java_util_jar_JarEntry$sub_refs	java_util_jar_JarEntry;
    _jc_java_util_zip_ZipEntry$sub_refs	java_util_zip_ZipEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_jar_JarEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_jar_JarEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_zip_ZipEntry$sub_nonrefs	java_util_zip_ZipEntry;
    _jc_java_util_jar_JarEntry$sub_nonrefs	java_util_jar_JarEntry;
};

// Object instance structure
struct _jc_java_util_jar_JarEntry$object {
	_jc_java_util_jar_JarEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_jar_JarEntry$vtype	*vtype;
	_jc_java_util_jar_JarEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_jar_JarEntry$vtype _jc_java_util_jar_JarEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_jar_JarEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_jar_JarEntry$class_object;

#endif	/* _JC_java_util_jar_JarEntry_H_ */
